@@ -2,7 +2,7 @@
  * sxid - suid, sgid file and directory checking
  * notify.c - notification functions
  *
- * Copyright (C) 1999 Ben Collins <bcollins@debian.org>
+ * Copyright (C) 1999, 2000, 2002 Ben Collins <bcollins@debian.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -21,22 +21,19 @@
  */
 
 #include <stdlib.h>
-#include <strings.h>
 #include <stdio.h>
 #include <sys/param.h>
 #include <unistd.h>
 #include <limits.h>
 
-#include "config.h"
-#include "structs.h"
-#include "globals.h"
-#include "conffile.h"
+#include "sxid.h"
 
-char current_time[1024];
+char current_time[MAXBUF];
 
+static
 void mail_header (FILE * output)
 {
-    char hostname_val[1024];
+    char hostname_val[MAXBUF];
 
     fprintf (output, "sXid Vers  : %s\n", sxid_version);
     fprintf (output, "Check run  : %s\n", current_time);
@@ -48,6 +45,9 @@ void mail_header (FILE * output)
 	fprintf (output, "Searching  : %s\n", config_options.search_paths);
     fprintf (output, "Excluding  : %s\n", config_options.exclude_paths);
     fprintf (output, "Ignore Dirs: %s\n", config_options.ignore_dirs);
+    if (config_options.extra_list[0] != '\0') {
+	fprintf (output, "Extra List : %s\n", config_options.extra_list);
+    }
     fprintf (output, "Forbidden  : %s\n", config_options.forbidden_paths);
     if (config_options.flags & FLAG_EFOR)
 	fprintf (output, "  (enforcing removal of s[ug]id bits in forbidden paths)\n");
@@ -65,13 +65,13 @@ void notify_email (void)
     rewind (mail_file);
 
 #ifdef CL_SUBJ
-    sprintf (buffer, "%s -s \"%s\" \"%s\"",
+    snprintf (buffer, sizeof(buffer), "%s -s \"%s\" \"%s\"",
 	config_options.mail_prog, changed ?
 	"List of changed s[ug]id files and folders" :
 	notify_diff ? "No changes found (persistent problems)" :
 	"No changes found (notice only)", config_options.email);
 #else
-    sprintf (buffer, "%s \"%s\"",
+    snprintf (buffer, sizeof(buffer), "%s \"%s\"",
 	config_options.mail_prog, config_options.email);
 #endif
 
